@@ -5,6 +5,7 @@ function(stacked = FALSE,
                             rose.y = NULL,
                             mar = rep(0.3,4),
                             rev.col = FALSE,
+                            shift = 0,
                             cex = 1,
                             col = NULL,
                             lty = 1:3,
@@ -35,6 +36,7 @@ function(stacked = FALSE,
                 mar = mar,
                 stacked = stacked,
                 rev.col = rev.col,
+                shift = shift,
                 cex = cex,
                 col = col,
                 lty = lty,
